==> silasdk-0.2.9rc0.tar.gz: silasdk-0.2.9rc0/silasdk/endpoints.py <==
endPoints = {
    "register": "/register",
    "checkKyc": "/check_kyc",
    "checkHandle": "/check_handle",
    "requestKyc": "/request_kyc",
    "issueSila": "/issue_sila",
    "redeemSila": "/redeem_sila",
    "transferSila": "/transfer_sila",
    "addCrypto": "/add_crypto",
    "addIdentity": "/add_identity",
    "createBond": "/create_bond",
    "checkHandle": "/check_handle",
    "getAccounts": "/get_accounts",
    "getAccountBalance": "/get_account_balance",
    "getTransactions": "/get_transactions",
    "registerOperator": "/register_operator",
    "linkAccount": "/link_account",
    "plaidSameDayAuth": "/plaid_sameday_auth",
    "registerWallet": "/register_wallet",
    "getWallets": "/get_wallets",
    "getWallet": "/get_wallet",
    "updateWallet": "/update_wallet",
    "deleteWallet": "/delete_wallet",
    "getSilaBalance": "get_sila_balance",
    "schemaUrl": "https://api.silamoney.com/0.2/getmessage?emptymessage=%sTestMessage",
    "apiUrl": "https://%s.silamoney.com/0.2",
    "silaBalanceProd": "https://silatokenapi.silamoney.com/silaBalance",
    "silaBalanceSandbox": "https://sandbox.silatokenapi.silamoney.com/silaBalance",
    "getBusinessTypes": "/get_business_types",
    "getBusinessRoles": "/get_business_roles",
    "getNaicsCategories": "/get_naics_categories",
    "linkBusinessMember": "/link_business_member",
    "unlinkBusinessMember": "/unlink_business_member",
    "getEntities": "/get_entities?",
    "getEntity": "/get_entity",
    "certifyBeneficialOwner": "/certify_beneficial_owner",
    "certifyBusiness": "/certify_business",
}

==> silasdk-0.2.10rc2.tar.gz: silasdk-0.2.10rc2/silasdk/endpoints.py <==
endPoints = {
    "register": "/register",
    "checkKyc": "/check_kyc",
    "checkHandle": "/check_handle",
    "requestKyc": "/request_kyc",
    "issueSila": "/issue_sila",
    "redeemSila": "/redeem_sila",
    "transferSila": "/transfer_sila",
    "addCrypto": "/add_crypto",
    "addIdentity": "/add_identity",
    "createBond": "/create_bond",
    "checkHandle": "/check_handle",
    "getAccounts": "/get_accounts",
    "getAccountBalance": "/get_account_balance",
    "getTransactions": "/get_transactions",
    "registerOperator": "/register_operator",
    "linkAccount": "/link_account",
    "plaidSameDayAuth": "/plaid_sameday_auth",
    "registerWallet": "/register_wallet",
    "getWallets": "/get_wallets",
    "getWallet": "/get_wallet",
    "updateWallet": "/update_wallet",
    "deleteWallet": "/delete_wallet",
    "getSilaBalance": "/get_sila_balance",
    "schemaUrl": "https://api.silamoney.com/0.2/getmessage?emptymessage=%sTestMessage",
    "apiUrl": "https://%s.silamoney.com/0.2",
    "silaBalanceProd": "https://silatokenapi.silamoney.com/silaBalance",
    "silaBalanceSandbox": "https://sandbox.silatokenapi.silamoney.com/silaBalance",
    "getBusinessTypes": "/get_business_types",
    "getBusinessRoles": "/get_business_roles",
    "getNaicsCategories": "/get_naics_categories",
    "linkBusinessMember": "/link_business_member",
    "unlinkBusinessMember": "/unlink_business_member",
    "getEntities": "/get_entities?",
    "getEntity": "/get_entity",
    "certifyBeneficialOwner": "/certify_beneficial_owner",
    "certifyBusiness": "/certify_business",
}
